==> agr-center-infrastructure-3.0.0-CLOUD-20221226.112038-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrChngApplyPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：agr_chng_apply
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrChngApplyPO implements Serializable {
	private static final long serialVersionUID =  7051721129353921471L;

	/**
	 * 变更申请ID
	 */
	private Long chngApplyId;
	/**
	 * 变更申请编号
	 */
	private String chngApplyNo;
	/**
	 * 协议变更类型
	 */
	private Integer chngType;
	/**
	 * 变更申请状态
	 */
	private Integer chngApplyStatus;
	/**
	 * 变更申请说明
	 */
	private String chngApplyComment;
	/**
	 * 变更申请意见
	 */
	private String chngApplyAdvise;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 原协议失效日期
	 */
	private Date preExpDate;
	private Date preExpDateStart;
	private Date preExpDateEnd;
	/**
	 * 新协议失效日期
	 */
	private Date postExpDate;
	private Date postExpDateStart;
	private Date postExpDateEnd;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 创建单位
	 */
	private Long createOrgId;
	/**
	 * 创建单位名称
	 */
	private String createOrgName;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 确认时间
	 */
	private Date confirmTime;
	private Date confirmTimeStart;
	private Date confirmTimeEnd;
	/**
	 * 确认人
	 */
	private String confirmName;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230106.111323-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrChngApplyPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：agr_chng_apply
 * 
 * @author auto_gen
 * @date 2022-11-22 10:31
 **/
@Data
public class AgrChngApplyPO implements Serializable {
	private static final long serialVersionUID =  -4597852987375577048L;

	/**
	 * 变更申请ID
	 */
	private Long chngApplyId;
	/**
	 * 变更申请编号
	 */
	private String chngApplyNo;
	/**
	 * 协议变更类型
	 */
	private Integer chngType;
	/**
	 * 变更申请状态
	 */
	private Integer chngApplyStatus;
	/**
	 * 变更申请说明
	 */
	private String chngApplyComment;
	/**
	 * 变更申请意见
	 */
	private String chngApplyAdvise;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 原协议失效日期
	 */
	private Date preExpDate;
	private Date preExpDateStart;
	private Date preExpDateEnd;
	/**
	 * 新协议失效日期
	 */
	private Date postExpDate;
	private Date postExpDateStart;
	private Date postExpDateEnd;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 创建单位
	 */
	private Long createOrgId;
	/**
	 * 创建单位名称
	 */
	private String createOrgName;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 确认时间
	 */
	private Date confirmTime;
	private Date confirmTimeStart;
	private Date confirmTimeEnd;
	/**
	 * 确认人
	 */
	private String confirmName;
	/**
	 * 排序
	 */
	private String orderBy;

}
